;##################################################################
;
;   P H O E N I X         F O R        T I - 8 5   /  T I - 8 6
;
;   Programmed by Patrick Davidson (pad@calc.org)
;        
;   This program is in the public domain.  There is no warranty.
;
;   This file was last updated August 16, 2002.
;
;##################################################################     

sidesdata       =$FA70
leftsidecoord   =$FB70
leftsidevel     =$FB71
rightsidecoord  =$FB72
rightsidevel    =$FB73

#define __85OR86__

;############## Initialize synchronization, screen sides, external levels

main:   ld      (iy+13),0               ; No-scroll text mode

        ld      hl,$fc00
        ld      (gfx_target),hl

        xor     a
        ld      (in_game),a

        ld      (initsp+1),sp           ; Save SP for exit

        call    set_up_sides            ; Set up scrolling side data

        ld      hl,timer_interrupt      ; Initialize interrupt
        call    INT_INSTALL

        ld      hl,level_table          ; Indicate no external level loaded
        ld      (level_addr),hl
        xor     a
        ld      (ext_level),a

        call    restore_game            ; Check for saved game

no_saved_game:
        ld      hl,$fc00                ; Set graphics frame
        ld      (smc_gfxmem_start+1),hl

        ld      a,4                     ; Set speed to normal (for title)
        ld      (speed),a

        call    check_level_loaded      ; Check for external level

;############## Title screen

redraw_title:
        call    CLEARLCD
        ld      hl,title_main

show_title:
        push    hl
        call    clear_buffer
        ld      hl,$fc00
        ld      bc,$1ff
        call    OTH_CLEAR
        pop     hl

        call    display_hl_msgs
        
title_loop:
        call    scroll_sides
        call    display_sides

        call    synchronize
        call    SUPER_GET_KEY
        sub     K_F3
        jr      z,show_instructions
        dec     a    
        jr      z,show_contact
        dec     a   
        jp      z,start_new_game
        cp      K_ALPHA-K_F1
        jr      z,show_highs
        cp      K_EXIT-K_F1
        jr      nz,title_loop

game_exit:
        call    INT_REMOVE
        ld      a,$7c
        out     (0),a
initsp: ld      sp,0
        ret

show_highs:
        call    no_high_score
        jr      redraw_title

show_contact:
        ld      hl,title_contact
        jr      show_title

show_instructions:
        ld      hl,title_instructions
        jr      show_title

;############## Title screen messages

title_main:
        .db     "   Phoenix ",VERSION,0
        .db     "  Programmed by",0
        .db     "Patrick  Davidson",0
        .db     " Charlie Ouyang ",0
        .db     "-----------------",0
        .db     " F1 - Start Game",0
        .db     "F2 - Contact Info",0
        .db     "F3 - Instructions",0
        .db     -1

title_instructions:
        .db     "Arrows: Move Ship",0
        .db     "Fn: Select Weapon",0
        .db     "2nd: Shoot Weapon",0
        .db     "MORE: Save + Exit",0
        .db     "ENTER: Pause Game",0
        .db     "+,-: Contrast Adj",0
        .db     0
        .db     "F1: Start Playing",0
        .db     -1

title_contact:
        .db     "E-Mail:",0
        .db     "     pad@calc.org",0
        .db     "World Wide Web:",0
        .db     "    pad.calc.org",0
        .db     -1

;############## Initialize a new game

start_new_game:
        call    initialize_game

pre_main_loop:
        ld      a,1
        ld      (in_game),a
        ld      hl,-6
        add     hl,sp
        ld      (collision_done+1),hl
        call    display_screen
        
;############## Game main loop
        
main_loop:
        call    frame_init

        call    hit_enemies            ; Collisions btw. bullets & enemies

        ld      a,(enemies_left)
        or      a
        jr      nz,no_load_level
        call    load_level
        ld      hl,in_game
        ld      a,(hl)
        or      a
        jr      nz,no_load_level
        inc     a
        ld      (timer),a
        ld      (hl),a
no_load_level:

        call    scroll_sides           ; Scroll sides (inside side buffer)
        call    clear_buffer           ; Prepare main display buffer

        call    init_rand

        call    do_player              ; Move and draw player
        call    do_companion           ; Move and draw companion ship

        call    enemies                ; Move and draw enemies

        call    player_bullets         ; Move and draw player bullets

        call    enemy_bullets          ; Move and draw enemy bullets
        call    hit_player             ; Collisions involving player

        call    prepare_indicator      ; Prepare shield indicator
                
        call    synchronize
        call    display_screen         ; Synchronize and swap buffers

        call    handle_input           ; Process control keys
        jr      main_loop

